<?php
/**
 * @file
 * Admin settings forms for connecting reference fields to subsites.
 */

/**
 * Administration settings form for defining sub-site field references. 
 *
 * The weight of the fields selected is used to detemind, which content
 * types (parents) should be associated with the different nodes.
 *
 * @param array $form_state
 * @return array
 */
function panels_subsites_ref_form(&$form_state) {
  // Check that content types have been selected.
  $content_types = array_filter(variable_get('panels_subsites_content_types', NULL));
  if (empty($content_types)) {
    drupal_set_message(t('You have not yet selected content types to associated with slugs. Click <a href="@link">here</a> to configure it.',
          array('@link' => url('admin/build/subsites'))));
    return;
  }

  // Add form style sheet.
  drupal_add_css(drupal_get_path('module', 'panels_subsites') . '/css/panels_subsites.css', 'module');

  // Find all node-reference fields.
  $fields = content_fields();
  $field_refs = array('none' => t('-- None --'));
  foreach ($fields as $field) {
    if ($field['type'] == 'nodereference') {
      $field_refs[$field['field_name']] = $field['field_name'];
    }
  }

  // Load all types.
  $types = node_get_types();

  // Convert selected content types into an array of user-friendly names.
  $content_type_options = array();
  foreach ($content_types as $key) {
    $content_type_options[$key] = $types[$key]->name;

   // Unset the selected content type from the list, as they are the ones
   // referenced.
   unset($types[$key]);
  }

  // Container for the actual field settings.
  $form['refs'] = array('#tree' => TRUE);

  // Build fieldset for each content type
  foreach ($types as $node_type => $obj) {
    $form['refs'][$node_type] = array(
      '#type' => 'fieldset',
      '#title' => $obj->name,
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );

    $settings = variable_get('panels_subsites_ref_' . $node_type, array());

    foreach (array_keys($content_type_options) as $key) {
      $record = (!empty($settings[$key])) ? $settings[$key] : array();

      // Build the form element.
      $form['refs'][$node_type][$key] = array(
        '#title' => $content_type_options[$key],
        '#type' => 'panels_subsites_ref',
        '#ref' => (!empty($record['ref'])) ? $record['ref'] : '',
        '#ref_options' => $field_refs,
        '#weight' => (!empty($record['weight'])) ? $record['weight'] : 0,
      );
    }
  }

  // Get system settings form look and feel.
  $form['buttons']['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save configuration'),
  );
  $form['#theme'] = 'system_settings_form';
  
  return $form;
}

/**
 * Submit handler for subsites reference settings form.
 */
function panels_subsites_ref_form_submit($form, &$form_state) {
  // Save reference settings for each node type.
  foreach ($form_state['values']['refs'] as $node_type => $values) {
    variable_set('panels_subsites_ref_' . $node_type, $values);
  }

  drupal_set_message(t('The configuration options have been saved.'));
}

